@@ -1,4 +1,4 @@
-# Copyright (c) 2002 Graham Barr <gbarr@pobox.com>. All rights reserved.
+# Copyright (c) 2004 Graham Barr <gbarr@pobox.com>. All rights reserved.
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 
@@ -8,7 +8,7 @@ use strict;
 use vars qw($VERSION @Plugins);
 use Carp;
 
-$VERSION = "2.06";
+$VERSION = "2.07";
 
 @Plugins = qw(
 	Authen::SASL::Cyrus
@@ -59,7 +59,7 @@ sub client_new { # $self, $service, $host, $secflags
   my $self = shift;
 
   foreach my $pkg (@Plugins) {
-    if (eval "require $pkg") {
+    if (eval "require $pkg" and $pkg->can("client_new")) {
       return ($self->{conn} = $pkg->client_new($self, @_));
     }
   }
@@ -67,6 +67,17 @@ sub client_new { # $self, $service, $host, $secflags
   croak "Cannot find a SASL Connection library";
 }
 
+sub server_new { # $self, $service, $host, $secflags
+  my $self = shift;
+
+  foreach my $pkg (@Plugins) {
+    if (eval "require $pkg" and $pkg->can("server_new")) {
+      return ($self->{conn} = $pkg->server_new($self, @_));
+    }
+  }
+  croak "Cannot find a SASL Connection library for server-side authentication";
+}
+
 # Compat.
 sub user {
   my $self = shift;
